@@ -12,6 +12,8 @@ problems: the code will get executed twice:
 
 Also see (1) from https://click.palletsprojects.com/en/5.x/setuptools/#setuptools-integration
 """
+import logging
+import sys
 from pathlib import Path
 from typing import Optional
 
@@ -19,12 +21,18 @@ import click
 from click.exceptions import Exit
 from loguru import logger
 
-from nitpick.constants import PROJECT_NAME
+from nitpick.constants import DOT_NITPICK_TOML, PROJECT_NAME
 from nitpick.core import Nitpick
 from nitpick.enums import OptionEnum
+from nitpick.exceptions import QuitComplainingError
 from nitpick.generic import relative_to_current_dir
 from nitpick.violations import Reporter
 
+VERBOSE_OPTION = click.option(
+    "--verbose", "-v", count=True, default=False, help="Increase logging verbosity (-v = INFO, -vv = DEBUG)"
+)
+FILES_ARGUMENT = click.argument("files", nargs=-1)
+
 
 @click.group()
 @click.option(
@@ -40,7 +48,7 @@ from nitpick.violations import Reporter
     help=OptionEnum.OFFLINE.value,
 )
 def nitpick_cli(project: Path = None, offline=False):  # pylint: disable=unused-argument
-    """Enforce the same configuration across multiple projects."""
+    """Enforce the same settings across multiple language-independent projects."""
 
 
 def get_nitpick(context: click.Context) -> Nitpick:
@@ -54,39 +62,60 @@ def get_nitpick(context: click.Context) -> Nitpick:
     return Nitpick.singleton().init(project_root, offline)
 
 
-@nitpick_cli.command()
-@click.option(
-    "--check",
-    "-c",
-    "check_only",
-    is_flag=True,
-    default=False,
-    help="Don't modify the configuration files, just print the difference."
-    " Return code 0 means nothing would change. Return code 1 means some files would be modified.",
-)
-@click.option("--verbose", "-v", is_flag=True, default=False, help="Verbose logging")
-@click.pass_context
-@click.argument("files", nargs=-1)
-def run(context, check_only, verbose, files):
-    """Apply suggestions to configuration files.
-
-    You can use partial and multiple file names in the FILES argument.
-    """
+def common_fix_or_check(context, verbose: int, files, check_only: bool) -> None:
+    """Common CLI code for both fix and check commands."""
     if verbose:
+        level = logging.INFO if verbose == 1 else logging.DEBUG
+
+        # https://loguru.readthedocs.io/en/stable/resources/recipes.html#changing-the-level-of-an-existing-handler
+        # https://github.com/Delgan/loguru/issues/138#issuecomment-525594566
+        logger.remove()
+        logger.add(sys.stderr, level=logging.getLevelName(level))
+
         logger.enable(PROJECT_NAME)
 
     nit = get_nitpick(context)
-    for fuss in nit.run(*files, apply=not check_only):
-        nit.echo(fuss.pretty)
+    try:
+        for fuss in nit.run(*files, fix=not check_only):
+            nit.echo(fuss.pretty)
+    except QuitComplainingError as err:
+        for fuss in err.violations:
+            click.echo(fuss.pretty)
+        raise Exit(2) from err
 
+    click.secho(Reporter.get_counts())
     if Reporter.manual or Reporter.fixed:
-        click.secho(Reporter.get_counts())
         raise Exit(1)
 
 
 @nitpick_cli.command()
 @click.pass_context
-@click.argument("files", nargs=-1)
+@VERBOSE_OPTION
+@FILES_ARGUMENT
+def fix(context, verbose, files):
+    """Fix files, modifying them directly.
+
+    You can use partial and multiple file names in the FILES argument.
+    """
+    common_fix_or_check(context, verbose, files, False)
+
+
+@nitpick_cli.command()
+@click.pass_context
+@VERBOSE_OPTION
+@FILES_ARGUMENT
+def check(context, verbose, files):
+    """Don't modify files, just print the differences.
+
+    Return code 0 means nothing would change. Return code 1 means some files would be modified.
+    You can use partial and multiple file names in the FILES argument.
+    """
+    common_fix_or_check(context, verbose, files, True)
+
+
+@nitpick_cli.command()
+@click.pass_context
+@FILES_ARGUMENT
 def ls(context, files):  # pylint: disable=invalid-name
     """List of files configured in the Nitpick style.
 
@@ -94,12 +123,31 @@ def ls(context, files):  # pylint: disable=invalid-name
     You can use partial and multiple file names in the FILES argument.
     """
     nit = get_nitpick(context)
-    violations = list(nit.project.merge_styles(nit.offline))
+    try:
+        violations = list(nit.project.merge_styles(nit.offline))
+        error_exit_code = 1
+    except QuitComplainingError as err:
+        violations = err.violations
+        error_exit_code = 2
     if violations:
         for fuss in violations:
             click.echo(fuss.pretty)
-        raise Exit(1)  # TODO: test ls with invalid style
+        raise Exit(error_exit_code)  # TODO: test ls with invalid style
 
     # TODO: test API .configured_files
     for file in nit.configured_files(*files):
         click.secho(relative_to_current_dir(file), fg="green" if file.exists() else "red")
+
+
+@nitpick_cli.command()
+@click.pass_context
+def init(context):
+    """Create a configuration file if it doesn't exist already."""
+    nit = get_nitpick(context)
+    config = nit.project.read_configuration()
+    if config.file:
+        click.secho(f"A config file already exists: {config.file.name}", fg="yellow")
+        raise Exit(1)
+
+    nit.project.create_configuration()
+    click.secho(f"Config file created: {DOT_NITPICK_TOML}", fg="green")
