@@ -176,7 +176,7 @@ class BaseFormat(metaclass=abc.ABCMeta):
                 {
                     k: v
                     for k, v in comparison.flat_expected.items()
-                    if k in comparison.flat_actual and comparison.flat_expected[k] != comparison.flat_actual[k]
+                    if k in comparison.flat_actual and v != comparison.flat_actual[k]
                 }
             )
         )
@@ -213,13 +213,19 @@ class TOMLFormat(BaseFormat):
         if self._loaded:
             return False
         if self.path is not None:
-            self._string = Path(self.path).read_text()
+            self._string = Path(self.path).read_text(encoding="UTF-8")
         if self._string is not None:
+            # TODO: I tried to replace toml by tomlkit, but lots of tests break.
+            #  The conversion to OrderedDict is not being done recursively (although I'm not sure this is a problem).
+            # self._data = OrderedDict(tomlkit.loads(self._string))
             self._data = toml.loads(self._string, _dict=OrderedDict)
         if self._data is not None:
             if isinstance(self._data, BaseFormat):
                 self._reformatted = self._data.reformatted
             else:
+                # TODO: tomlkit.dumps() renders comments and I didn't find a way to turn this off,
+                #  but comments are being lost when the TOML plugin does dict comparisons.
+                # self._reformatted = tomlkit.dumps(OrderedDict(self._data), sort_keys=True)
                 self._reformatted = toml.dumps(self._data)
         self._loaded = True
         return True
@@ -239,7 +245,7 @@ class YAMLFormat(BaseFormat):
         yaml.sequence_dash_offset = 2
 
         if self.path is not None:
-            self._string = Path(self.path).read_text()
+            self._string = Path(self.path).read_text(encoding="UTF-8")
         if self._string is not None:
             self._data = yaml.load(io.StringIO(self._string))
         if self._data is not None:
@@ -280,7 +286,7 @@ class JSONFormat(BaseFormat):
         if self._loaded:
             return False
         if self.path is not None:
-            self._string = Path(self.path).read_text()
+            self._string = Path(self.path).read_text(encoding="UTF-8")
         if self._string is not None:
             self._data = json.loads(self._string, object_pairs_hook=OrderedDict)
         if self._data is not None:
