@@ -38,11 +38,12 @@ class IniPlugin(NitpickPlugin):
     - `setup.cfg <https://docs.python.org/3/distutils/configfile.html>`_
     - `.editorconfig <https://editorconfig.org/>`_
     - `tox.ini <https://github.com/tox-dev/tox>`_
+    - `.pylintrc <https://pylint.readthedocs.io/en/latest/user_guide/run.html#command-line-options>`_
 
     Style examples enforcing values on INI files: :ref:`flake8 configuration <example-flake8>`.
     """
 
-    can_apply = True
+    can_fix = True
     identify_tags = {"ini", "editorconfig"}
     violation_base_code = 320
 
@@ -96,7 +97,7 @@ class IniPlugin(NitpickPlugin):
         """Write the new file."""
         try:
             if self.needs_top_section:
-                self.file_path.write_text(self.remove_top_section(str(self.updater)))
+                self.file_path.write_text(self.contents_without_top_section(str(self.updater)))
                 return None
 
             if file_exists:
@@ -108,9 +109,9 @@ class IniPlugin(NitpickPlugin):
         return None
 
     @staticmethod
-    def remove_top_section(multiline_text: str) -> str:
-        """Remove the temporary top section from multiline text."""
-        return "\n".join(line for line in multiline_text.splitlines() if TOP_SECTION not in line)
+    def contents_without_top_section(multiline_text: str) -> str:
+        """Remove the temporary top section from multiline text, and keep the newline at the end of the file."""
+        return "\n".join(line for line in multiline_text.splitlines() if TOP_SECTION not in line) + "\n"
 
     def get_missing_output(self) -> str:
         """Get a missing output string example from the missing sections in an INI file."""
@@ -121,13 +122,14 @@ class IniPlugin(NitpickPlugin):
         parser = ConfigParser()
         for section in sorted(missing, key=lambda s: "0" if s == TOP_SECTION else f"1{s}"):
             expected_config: Dict = self.expected_config[section]
-            if self.apply:
+            if self.fix:
                 if self.updater.last_block:
                     self.updater.last_block.add_after.space(1)
                 self.updater.add_section(section)
                 self.updater[section].update(expected_config)
+                self.dirty = True
             parser[section] = expected_config
-        return self.remove_top_section(self.get_example_cfg(parser))
+        return self.contents_without_top_section(self.get_example_cfg(parser))
 
     # TODO: convert the contents to dict (with IniConfig().sections?) and mimic other plugins doing dict diffs
     def enforce_rules(self) -> Iterator[Fuss]:
@@ -171,7 +173,7 @@ class IniPlugin(NitpickPlugin):
             return
 
         # Don't change the file if there was a parsing error
-        self.apply = False
+        self.fix = False
         yield self.reporter.make_fuss(Violations.PARSING_ERROR, cls=parsing_err.__class__.__name__, msg=parsing_err)
         raise Error
 
@@ -179,7 +181,7 @@ class IniPlugin(NitpickPlugin):
         """Enforce missing sections."""
         missing = self.get_missing_output()
         if missing:
-            yield self.reporter.make_fuss(Violations.MISSING_SECTIONS, missing, self.apply)
+            yield self.reporter.make_fuss(Violations.MISSING_SECTIONS, missing, self.fix)
 
     def enforce_section(self, section: str) -> Iterator[Fuss]:
         """Enforce rules for a section."""
@@ -205,15 +207,16 @@ class IniPlugin(NitpickPlugin):
 
         joined_values = ",".join(sorted(missing))
         value_to_append = f",{joined_values}"
-        if self.apply:
+        if self.fix:
             self.updater[section][key].value += value_to_append
+            self.dirty = True
         section_header = "" if section == TOP_SECTION else f"[{section}]\n"
         # TODO: proper testing of top section with separated values in https://github.com/andreoliwa/nitpick/issues/271
         yield self.reporter.make_fuss(
             Violations.MISSING_VALUES_IN_LIST,
             f"{section_header}{key} = (...){value_to_append}",
             key=key,
-            fixed=self.apply,
+            fixed=self.fix,
         )
 
     def compare_different_keys(self, section, key, raw_actual: Any, raw_expected: Any) -> Iterator[Fuss]:
@@ -228,15 +231,16 @@ class IniPlugin(NitpickPlugin):
         if actual == expected:
             return
 
-        if self.apply:
+        if self.fix:
             self.updater[section][key].value = expected
+            self.dirty = True
         if section == TOP_SECTION:
             yield self.reporter.make_fuss(
                 Violations.TOP_SECTION_HAS_DIFFERENT_VALUE,
                 f"{key} = {raw_expected}",
                 key=key,
                 actual=raw_actual,
-                fixed=self.apply,
+                fixed=self.fix,
             )
         else:
             yield self.reporter.make_fuss(
@@ -245,7 +249,7 @@ class IniPlugin(NitpickPlugin):
                 section=section,
                 key=key,
                 actual=raw_actual,
-                fixed=self.apply,
+                fixed=self.fix,
             )
 
     def show_missing_keys(self, section: str, values: List[Tuple[str, Any]]) -> Iterator[Fuss]:
@@ -258,22 +262,23 @@ class IniPlugin(NitpickPlugin):
 
         if section == TOP_SECTION:
             yield self.reporter.make_fuss(
-                Violations.TOP_SECTION_MISSING_OPTION, self.remove_top_section(output), self.apply
+                Violations.TOP_SECTION_MISSING_OPTION, self.contents_without_top_section(output), self.fix
             )
         else:
-            yield self.reporter.make_fuss(Violations.MISSING_OPTION, output, self.apply, section=section)
+            yield self.reporter.make_fuss(Violations.MISSING_OPTION, output, self.fix, section=section)
 
     def add_options_before_space(self, section: str, options: OrderedDict) -> None:
         """Add new options before a blank line in the end of the section."""
-        if not self.apply:
+        if not self.fix:
             return
 
         space_removed = False
         while isinstance(self.updater[section].last_block, Space):
             space_removed = True
-            self.updater[section].last_block.remove()
+            self.updater[section].last_block.detach()
 
         self.updater[section].update(options)
+        self.dirty = True
 
         if space_removed:
             self.updater[section].last_block.add_after.space(1)
