@@ -69,14 +69,14 @@ class Violations(ViolationEnum):
     REPO_DOES_NOT_EXIST = (333, ": repo {repo!r} does not exist under {key!r}")
     MISSING_KEY_IN_REPO = (334, ": missing {key!r} in repo {repo!r}")
     STYLE_FILE_MISSING_NAME = (335, ": style file is missing {key!r} in repo {repo!r}")
-    MISSING_KEY_IN_HOOK = (336, ": style file is missing {key!r} in hook:\n{yaml}")
-    MISSING_HOOK_WITH_ID = (337, ": missing hook with id {id!r}:\n{yaml}")
+    MISSING_KEY_IN_HOOK = (336, ": style file is missing {key!r} in hook:")
+    MISSING_HOOK_WITH_ID = (337, ": missing hook with id {id!r}:")
 
 
 class PreCommitPlugin(NitpickPlugin):
     """Enforce configuration for `.pre-commit-config.yaml <https://pre-commit.com/#pre-commit-configyaml---top-level>`_.
 
-    Example: :ref:`the default pre-commit hooks <default-pre-commit-hooks>`.
+    Style example: :ref:`the default pre-commit hooks <example-pre-commit-hooks>`.
     """
 
     filename = PRE_COMMIT_CONFIG_YAML
@@ -94,15 +94,10 @@ class PreCommitPlugin(NitpickPlugin):
         original_repos = original.pop(KEY_REPOS, [])
         suggested: Dict[str, Any] = {KEY_REPOS: []} if original_repos else {}
         for repo in original_repos:
-            new_repo = dict(repo)
-            hooks_or_yaml = repo.get(KEY_HOOKS, repo.get(KEY_YAML, {}))
-            if KEY_YAML in repo:
-                repo_list = YAMLFormat(string=hooks_or_yaml).as_list
-                suggested[KEY_REPOS].extend(repo_list)
-            else:
-                # TODO: show a deprecation warning for this case
-                new_repo[KEY_HOOKS] = YAMLFormat(string=hooks_or_yaml).as_data
-                suggested[KEY_REPOS].append(new_repo)
+            if KEY_YAML not in repo:
+                continue
+            repo_list = YAMLFormat(string=repo[KEY_YAML]).as_list
+            suggested[KEY_REPOS].extend(repo_list)
         suggested.update(original)
         return YAMLFormat(data=suggested).reformatted
 
@@ -176,7 +171,6 @@ class PreCommitPlugin(NitpickPlugin):
             yield self.reporter.make_fuss(Violations.MISSING_KEY_IN_REPO, key=KEY_HOOKS, repo=repo_name)
             return
 
-        actual_hooks = actual_repo_dict.get(KEY_HOOKS) or []
         yaml_expected_hooks = repo_data.get(KEY_HOOKS)
         if not yaml_expected_hooks:
             yield self.reporter.make_fuss(Violations.STYLE_FILE_MISSING_NAME, key=KEY_HOOKS, repo=repo_name)
@@ -187,13 +181,10 @@ class PreCommitPlugin(NitpickPlugin):
             hook_id = expected_dict.get(KEY_ID)
             expected_yaml = self.format_hook(expected_dict).rstrip()
             if not hook_id:
-                yield self.reporter.make_fuss(Violations.MISSING_KEY_IN_HOOK, key=KEY_ID, yaml=expected_yaml)
+                yield self.reporter.make_fuss(Violations.MISSING_KEY_IN_HOOK, expected_yaml, key=KEY_ID)
                 continue
 
-            actual_dict = find_object_by_key(actual_hooks, KEY_ID, hook_id)
-            if not actual_dict:
-                yield self.reporter.make_fuss(Violations.MISSING_HOOK_WITH_ID, id=hook_id, yaml=expected_yaml)
-                continue
+            yield self.reporter.make_fuss(Violations.MISSING_HOOK_WITH_ID, expected_yaml, id=hook_id)
 
     @staticmethod
     def format_hook(expected_dict) -> str:
@@ -210,7 +201,7 @@ class PreCommitPlugin(NitpickPlugin):
 
 @hookimpl
 def plugin_class() -> Type["NitpickPlugin"]:
-    """You should return your plugin class here."""
+    """Handle pre-commit config file."""
     return PreCommitPlugin
 
 
