@@ -1,12 +1,13 @@
 """Type definitions."""
 from pathlib import Path
-from typing import Any, Dict, List, Tuple, Type, Union
+from typing import Any, Dict, Iterable, List, Tuple, Type, Union
 
 from ruamel.yaml.comments import CommentedMap, CommentedSeq
 
 PathOrStr = Union[Path, str]
 JsonDict = Dict[str, Any]
 StrOrList = Union[str, List[str]]
+StrOrIterable = Union[str, Iterable[str]]
 Flake8Error = Tuple[int, int, str, Type]
 YamlData = Union[CommentedSeq, CommentedMap]
 
